##############
minushalf
##############
.. image:: https://readthedocs.org/projects/minushalf/badge/
   :target: https://minushalf.readthedocs.org
   :alt: Documentation Status

.. image:: https://img.shields.io/lgtm/alerts/g/hentt30/minushalf.svg?logo=lgtm&logoWidth=18
   :target: https://lgtm.com/projects/g/hentt30/minushalf/alerts/
   :alt: Total alerts

.. image:: https://img.shields.io/lgtm/grade/python/g/hentt30/minushalf.svg?logo=lgtm&logoWidth=18
   :target: https://lgtm.com/projects/g/hentt30/minushalf/context:python
   :alt: Language grade: Python

What is minushalf?
----------------------
Minushalf is a CLI developed by GMSN that aims to automate 
the application of the DFT -1/2 method. The commands available in this 
CLI automate both the entire process and each of its steps in order to be 
used by the user for any purposes.

More information
------------------------
- `Read the docs <https://minushalf.readthedocs.io/en/latest/>`_
- `Known GMSN <http://www.gmsn.ita.br/>`_
